#ifndef _GENERAL_H
#include "General.h"
#endif

#ifndef _READ_IN_DATA_H
#include "Read_in_data.h"
#endif

#ifndef _LIKFUNCTIONS_H
#include "LikFunctions.h"
#endif

#ifndef _ERRORMAT_H
#include "ErrorMat.h"
#endif

#ifndef _SPECRAND_H
#include "SpecRand.h"
#endif

#ifndef _SAMPG_H
#include "SampG.h"
#endif

#ifndef _SAMPDOMG_H
#include "SampDomG.h"
#endif

#ifndef _SAMPP_H
#include "SampP.h"
#endif

#ifndef _SAMPD_H
#include "SampD.h"
#endif

#ifndef _SAMPS_H
#include "SampS.h"
#endif

#ifndef _CALCX_G_H
#include "calcX_G.h"
#endif

